@@ -2,19 +2,20 @@
 """
 from __future__ import annotations
 
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from enum import Enum
 
 UNKNOWN = "UNKNOWN"
+JOINS = ";; "
 
 
-@dataclass(unsafe_hash=True)
+@dataclass(unsafe_hash=True, order=True)
 class PackageInfo:
 	"""PackageInfo type."""
 
 	name: str
 	version: str = UNKNOWN
-	namever: str = UNKNOWN
+	namever: str = field(init=False)
 	size: int = -1
 	homePage: str = UNKNOWN
 	author: str = UNKNOWN
@@ -22,6 +23,9 @@ class PackageInfo:
 	licenseCompat: bool = False
 	errorCode: int = 0
 
+	def __post_init__(self):
+		self.namever = f"{self.name}-{self.version}"
+
 
 class License(Enum):
 	"""License Enum to hold a set of potential licenses."""
